Cite this package
-----------------

.. |JOSS| image:: https://joss.theoj.org/papers/10.21105/joss.07940/status.svg
  :alt: doi:10.21105/joss.07940
  :target: https://doi.org/10.21105/joss.07940

If you use this package for your scientific works, please cite |JOSS|. You can directly use the following BibTeX entry:

.. code-block:: bibtex

    @article{Elasticipy,
        doi = {10.21105/joss.07940},
        url = {https://doi.org/10.21105/joss.07940},
        year = {2025},
        publisher = {The Open Journal},
        volume = {10},
        number = {115},
        pages = {7940},
        author = {Depriester, Dorian and Kubler, Régis},
        title = {Elasticipy: A Python package for linear elasticity and tensor analysis},
        journal = {Journal of Open Source Software}
    }